@@ -11,20 +11,12 @@ MyPy will force you to only use items in the Protocol.
 
 from __future__ import annotations
 
-import sys
 from collections.abc import Iterator, Sequence
-from typing import Any, Tuple, TypeVar, Union
+from typing import Any, Protocol, Tuple, TypeVar, Union, runtime_checkable
 
 # NumPy 1.20+ will work much, much better than previous versions when type checking
 import numpy as np
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Protocol, runtime_checkable
-
-else:
-    from typing import Protocol, runtime_checkable
-
-
 protocol_version = (1, 2)
 
 # Known kinds of histograms. A Producer can add Kinds not defined here; a
@@ -70,8 +62,7 @@ class PlottableAxisGeneric(Protocol[T_co]):
     # available on all histograms and not part of the Protocol.
 
     @property
-    def traits(self) -> PlottableTraits:
-        ...
+    def traits(self) -> PlottableTraits: ...
 
     def __getitem__(self, index: int) -> T_co:
         """
@@ -105,12 +96,10 @@ PlottableAxis = Union[PlottableAxisContinuous, PlottableAxisInt, PlottableAxisSt
 @runtime_checkable
 class PlottableHistogram(Protocol):
     @property
-    def axes(self) -> Sequence[PlottableAxis]:
-        ...
+    def axes(self) -> Sequence[PlottableAxis]: ...
 
     @property
-    def kind(self) -> Kind:
-        ...
+    def kind(self) -> Kind: ...
 
     # All methods can have a flow=False argument - not part of this Protocol.
     # If this is included, it should return an array with flow bins added,
